package Source::Repository::Mass::ALTLinuxBackport;

use strict;
use warnings;
#use Carp;

use Source::Repository::Mass;
use RPM::Source::Convert::ALTLinuxBackport;
use Source::Repository::Matcher;
# use of DistroMap Matcher looks excess here due to suppress_rename=1
# no Source::Repository::Matcher::DistroMap;
use RPM::Source::Shared::Resource::DistroMap;

use Source::Repository::Mass::Transform;

our @ISA = qw/Source::Repository::Mass/;
our $backport_suffix;
our $destbranch='t7';

our $verbose=0;

$Source::Repository::Mass::Transform::suppress_rename=1;
$Source::Repository::Mass::strategy = 'newer';
$Source::Repository::Mass::epoch_comparator=\&Source::Package::Comparators::rpm40_epoch_comparator;
$Source::Repository::Mass::version_comparator=\&Source::Package::Comparators::rpm_plus_perl_version_comparator;
$Source::Repository::Mass::release_comparator=\&altbackport_release_comparator;

$DistroMap::default_originrepo='altlinux';
$DistroMap::default_originbranch='sisyphus';
$DistroMap::default_destrepo='altlinux';

sub new {
    my $class = shift;
    $DistroMap::default_destbranch=&RPM::Source::Convert::ALTLinuxBackport::_suffix2destbranch($backport_suffix) if ($backport_suffix);
    my $self = $class->SUPER::new(@_);
    $destbranch=$DistroMap::default_destbranch;
    $backport_suffix=&RPM::Source::Convert::ALTLinuxBackport::_destbranch2suffix($DistroMap::default_destbranch) unless $backport_suffix;
    return $self;
};

# ===== STATIC ===

sub altbackport_release_comparator {
    my ($origin,$dest) =@_;
    my $originrelease=$origin->release;
    my $destrelease=$dest->release;
    my $autoportsrelease=&RPM::Source::Convert::ALTLinuxBackport::_nextrel_altbackport_raw($originrelease, $backport_suffix);
    return 0 if $destrelease eq $autoportsrelease or $destrelease eq $originrelease;
    # Binary "cmp" returns -1, 0, or 1 depending on whether the left argument
    # is stringwise less than, equal to, or greater than the right argument.
    my $cmp=RPM::evrcmp($originrelease,$destrelease);
    print STDERR "$originrelease rpmcmp $destrelease = $cmp\n" if $verbose>1;
    return $cmp if $cmp <= 0;
    $cmp=RPM::evrcmp($autoportsrelease,$destrelease);
    print STDERR "$autoportsrelease rpmcmp $destrelease = $cmp\n" if $verbose>1;
    return $cmp;
}

1;
