package Source::Repository::Mass::ALTLinuxImport;

use strict;
use warnings;
use Carp;
use RPM qw/evrcmp/;

use Source::Repository::Mass;
use Source::Repository::Matcher;
use Source::Repository::Matcher::DistroMap;
use Source::Repository::Mass::Transform::Embedded;
use Source::Package::Comparators::Raw;
use RPM::Source::Convert::ALTLinuxImport;

our @ISA = qw/Source::Repository::Mass::Transform::Embedded/;

our $verbose=0;

$DistroMap::default_destrepo='altlinux';
$Source::Repository::Mass::strategy='newer';
$Source::Repository::Mass::version_comparator=\&Source::Package::Comparators::rpm_plus_perl_version_comparator;
$Source::Repository::Mass::release_comparator=\&altimport_release_comparator;
$RPM::Source::Transformation::Factory::RaiseRelease::version_comparator=\&Source::Package::Comparators::Raw::_rpm_plus_perl_version_cmp;

my ($ALTROOT)= grep {-d $_} qw'/var/ftp/pub/Linux/ALT /var/ftp/pub/ALTLinux /ALT ALT /srv/public/mirror';
$DESTPATH="~/hasher/repo/SRPMS.hasher:~/hasher/repo/SRPMS.hasher.S";
if ($ALTROOT) {
    foreach my $pathentry (qw!Sisyphus fcimport/Sisyphus mgaimport/Sisyphus autoimports/Sisyphus t7/branch p7/branch t6/branch p6/branch 5.1/branch!) {
	my $dir_to_add=$ALTROOT.'/'.$pathentry.'/files/SRPMS';
	$DESTPATH .= ':'.$dir_to_add  if -d $dir_to_add;
	$dir_to_add="$ALTROOT/mirrors/".$pathentry.'/files/SRPMS';
	$DESTPATH .= ':'.$dir_to_add  if -d $dir_to_add;
    }
}

#Binary "cmp" returns -1, 0, or 1 depending on whether the left argument
#is stringwise less than, equal to, or greater than the right argument.
sub altimport_release_comparator {
    my ($origin, $dest) =@_;
    my $originrelease=$origin->release;
    my $destrelease=$dest->release;

    # (?=(?:\.|$)) due to smth like Release: 7%{?dist}.1
    $originrelease=~s/\.(fc|mga)\d+(\.R)?(?=(?:\.|$))//;

    if ($destrelease=~/^alt([^_]+)_(.+)$/) {
	my $destextrel=$2;
	my $cmp=evrcmp($originrelease,$destextrel);
	print STDERR "ALTLinuxImport relcmp: $originrelease rpmcmp $destextrel = $cmp\n" if $verbose;
	return $cmp;
    } else {
	warn "WARNING: non-robotic dest release $destrelease in ".$dest->name.'-'.$dest->version;
    }
    return 1;
}

1;
