package Source::Repository::Mass::SkipPkg::MTime;

use strict;
use warnings;
use Carp;
use File::Basename;

use Source::Repository::Mass::SkipPkg;
our @ISA=qw/Source::Repository::Mass::SkipPkg/;
push @Source::Repository::Mass::PkgFilter::PKG_SKIP_CLASSES, __PACKAGE__;

our $verbose=1;
our (
$arg_origin_mtime_less,
$arg_origin_mtime_more,
$arg_dest_mtime_less,
$arg_dest_mtime_more,
    );

our @LONGOPT = (
    "dest-mtime-less=f"	=> \$arg_dest_mtime_less,
    "dest-mtime-more=f"	=> \$arg_dest_mtime_more,
    "origin-mtime-less=f"	=> \$arg_origin_mtime_less,
    "origin-mtime-more=f"	=> \$arg_origin_mtime_more,
    );

sub longopt_usage {
    print "  Limit mass operation by mtime options:
	--dest-mtime-less <days> select dest packages that has -M less than value.
	--dest-mtime-more <days> select dest packages that has -M more than value.
	--origin-mtime-less <days> select origin packages that has -M less than value.
	--origin-mtime-more <days> select origin packages that has -M more than value.
";
}

sub process_options {
    return if defined $arg_origin_mtime_less
or defined $arg_origin_mtime_more
or defined $arg_dest_mtime_less
or defined $arg_dest_mtime_more;
    @Source::Repository::Mass::Container::PKG_SKIP_CLASSES=grep {$_ ne __PACKAGE__} @Source::Repository::Mass::Container::PKG_SKIP_CLASSES;
}

sub pkgfilter {
    my ($self,$pkgpair)=@_;
    print STDERR "Source::Repository::Mass::SkipPkg::PkgMTime is called\n" if $verbose>1;
    if (defined $arg_origin_mtime_less or defined $arg_origin_mtime_more) {
	my $origin=$pkgpair->origin;
	unless ($origin) {
	    my $originname=$pkgpair->originname;
	    my $destname=$pkgpair->destname;
	    print STDERR "Oops! no origin found for $originname ($destname). Skipping\n";
	    return 1;
	}
	if (defined $arg_origin_mtime_less) {
	    return &verbose_test_mtime_less($origin->file,$arg_origin_mtime_less);
	} elsif (defined $arg_origin_mtime_more) {
	    return &verbose_test_mtime_more($origin->file,$arg_origin_mtime_more);
	}
    } elsif (defined $arg_dest_mtime_less or defined $arg_dest_mtime_more) {
	my $dest=$pkgpair->dest;
	unless ($dest) {
	    my $originname=$pkgpair->originname;
	    my $destname=$pkgpair->destname;
	    print STDERR "Oops! no dest found for $originname ($destname). Skipping\n";
	    return 1;
	}
	if (defined $arg_dest_mtime_less) {
	    return &verbose_test_mtime_less($dest->file,$arg_dest_mtime_less);
	} elsif (defined $arg_dest_mtime_more) {
	    return &verbose_test_mtime_more($dest->file,$arg_dest_mtime_more);
	}
    }
    return 0;
}

sub verbose_test_mtime_less {
    my ($file, $mtime)=@_;
    my $cmp = -M $file >= $mtime;
    print STDERR "SkipPkg::MTime: skipped $file: too old\n" if $cmp and $verbose;
    return $cmp;
}

sub verbose_test_mtime_more {
    my ($file, $mtime)=@_;
    my $cmp = -M $file <= $mtime;
    print STDERR "SkipPkg::MTime: skipped $file: too new\n" if $cmp and $verbose;
    return $cmp;
}

1;
