package Source::Repository::Mass::SkipPkg::Timestamp;

use strict;
use warnings;
use Carp;
use File::Basename;

use Source::Repository::Mass::SkipPkg;
our @ISA=qw/Source::Repository::Mass::SkipPkg/;
push @Source::Repository::Mass::PkgFilter::PKG_SKIP_CLASSES, __PACKAGE__;

our $verbose;
our ($arg_timestampdir);
our $arg_timestamp_expire=7; # in days

our @LONGOPT = (
    "timestampdir=s"	=> \$arg_timestampdir,
    "timestamp-expire=f"	=> \$arg_timestamp_expire,
    );

sub longopt_usage {
    print "  Limit mass operation by timestamp options:
	--timestampdir /path/to/dir to store timestamps
	--timestamp-expire <days> days til the timestamp expire.
";
}

sub pkgfilter {
    my ($self,$pkgpair)=@_;
    return 0 unless defined $arg_timestampdir;
    unless ($pkgpair->origin) {
	my $originname=$pkgpair->originname;
	my $destname=$pkgpair->destname;
	print STDERR "Oops! no origin found for $originname ($destname). Skipping\n";
	return 1;
    }
    my $timestamp_file=&__srpmfile2timestamp($pkgpair->origin->file);
    return 1 if -M $timestamp_file and ($arg_timestamp_expire==0 or -M $timestamp_file < $arg_timestamp_expire);
    return 0;
}

sub postpkgfilter {
    my ($self,$pkgpair)=@_;
    return unless defined $arg_timestampdir;
    &__run('touch',&__srpmfile2timestamp($pkgpair->origin->file));
};


#------------------------------------------
#    private utilities
#------------------------------------------

sub __run {
    print STDERR "running: ", join(' ',@_),"\n" if $verbose;
    system(@_)==0 or Carp::confess "command failed: ".join(' ',@_);
}

sub __srpmfile2timestamp {
    my ($rpm)=@_;
    return $arg_timestampdir.'/'.basename($rpm).'.stamp';
}

1;
