package Source::Repository::Mass::Transform::Embedded;

use strict;
use warnings;
use Source::Repository::Mass::Transform;
use RPM::Source::Transformation::PkgWriter;

our @ISA = qw(Source::Repository::Mass::Transform);
our $embedded_class='RPM::Source::Transform';

$RPM::Source::Transformation::PkgWriter::outputdir=$Source::Repository::Mass::Transform::DEFAULT_OUTDIR;

push @Source::Repository::Mass::EXT_LONGOPT_CLASSES, __PACKAGE__;

sub process_options {
    $embedded_class->process_options;
}

sub new {
    my $class = shift;
    my $self = $class->SUPER::new(@_);
    $RPM::Source::Transform::verbose=$Source::Repository::Mass::verbose;
    $self->{-transform}=$embedded_class->new(-embedded=>1);
    return $self;
};

sub process_pair {
    my ($self,$pkgpair,$transaction_name,$transaction_count)=@_;
    my ($originname, $destname)=($pkgpair->originname,$pkgpair->destname);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    if (not $origin) {
	print STDERR "ERROR: origin file for $originname not found.\n";
	return;
    }
    my $converter=$self->{-transform};
    my $converter_opt=$converter->mk_opt();
    $converter_opt->{-rename}=$destname if $destname ne $originname and not $Source::Repository::Mass::Transform::suppress_rename;

    $converter_opt->{-transaction_output_subdir} = &Source::Repository::Mass::Transform::__transaction_output_subdir($transaction_name,$transaction_count) if defined($transaction_name);

    my ($spec,$parent)=$self->get_spec_parent($pkgpair,$converter,$converter_opt);

    if ($Source::Repository::Mass::verbose) {
	print STDERR "info: origin: $spec->{SOURCERPM}\n" if ($spec and $spec->{SOURCERPM});
	print STDERR "info: parent: $parent->{SOURCERPM}\n" if $parent and $parent->{SOURCERPM};
    }

    #$self->process_pair_hook($pkgpair, $converter_opt, $spec, $parent);
    $converter->transform_once($spec,$parent,$converter_opt);

    print "---*---\n";
}

sub get_spec_parent {
    my ($self,$pkgpair,$converter,$converter_opt)=@_;
    my ($spec,$parent);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    $spec=$converter->get_spec($self->{-originrepo}->pkg4rpmeditor($origin)) if $origin;
    my $parentref;
    $parentref=$RPM::Source::TransformContainer::ParentProvider->get() if $RPM::Source::TransformContainer::ParentProvider;
    $parentref||=$self->{-destrepo}->pkg4rpmeditor($dest) if $dest;
    $parent=$converter->get_parent($parentref) if $parentref;
    return ($spec,$parent);
}

1;
