package Source::Repository::Mass::Transform::PassThrough;

use strict;
use warnings;
use String::ShellQuote;
use RPM::Source::Shared::ResourceContainer;
use Source::Repository::Mass::Transform;
our @ISA = qw(Source::Repository::Mass::Transform);

$RPM::Source::Shared::ResourceContainer::pass_through_mode=1;
push @Source::Repository::Mass::EXT_LONGOPT_CLASSES, __PACKAGE__;

our $originimport="srpmconvert";
our $verbose;

sub get_longopt {
    #print join('<->', RPM::Source::Transform->get_longopt),"\n";
    #return &Source::Repository::Mass::Transform::PassThrough::Getopt::passthrough2({@Source::Repository::Mass::EXT_OPTS}, RPM::Source::Transform->get_longopt);
    return &Source::Repository::Mass::Transform::PassThrough::Getopt::passthrough(RPM::Source::Transform->get_longopt);
}

sub process_options{}

sub process_pair_hook {}

sub process_pair {
    my ($self,$pkgpair,$transaction_name,$transaction_count)=@_;
    my ($originname, $destname)=($pkgpair->originname,$pkgpair->destname);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    my @args;

    # less verbose by 1; assumed verbose=1 is for mass only
    for (my $i=0; $i<$Source::Repository::Mass::verbose-1; $i++) {
	push @args, '--verbose';
    }

    push @args, '--rename', $destname if $destname ne $originname and not $Source::Repository::Mass::Transform::suppress_rename;

    push @args, '--outdir' , $Source::Repository::Mass::Transform::DEFAULT_OUTDIR;
    push @args, '--transaction-output-subdir', &Source::Repository::Mass::Transform::__transaction_output_subdir($transaction_name,$transaction_count) if defined($transaction_name);

#    if ($parent) {
#	push @args, '--parent', $parent;
#    } else {
	push @args, '--parent', $dest->file if $dest;
#    }
    if ($origin) {
	push @args, $origin->file;
    } else {
	print STDERR "ERROR: origin file for $originname not found.\n";
	return;
    }
    push @args, &Source::Repository::Mass::Transform::PassThrough::Getopt::cat_options(), @RPM::Source::Shared::ResourceContainer::PASS_THROUGH_OPTS;
    print STDERR "PASS_THROUGH_OPTS: ",join('<->', @RPM::Source::Shared::ResourceContainer::PASS_THROUGH_OPTS),"\n" if $verbose;

    $self->process_pair_hook(\@args, $pkgpair);

    print join(' ',map {shell_quote_best_effort $_} $originimport,@args),"\n";

    (system($originimport,@args)==0) or die "$originimport failed\n";
    print "---*---\n";
}

#----------------------------------------------------------

package Source::Repository::Mass::Transform::PassThrough::Getopt;

use strict;
use warnings;

my @COLLECT;
my %known_noarg_opts;

our $verbose=0;

#sub new {
#    my $class = shift;
#    my $self = {@_};
#    bless $self, $class;
#}

sub _collect {
    my @in=@_;
    push @COLLECT, [@in];
#    print STDERR "collected: ",join ('-->',@in),"\n";
}

sub passthrough {
    my (@opt)=@_;
    @COLLECT=();
    my @processed;
    while (@opt) {
	my $optspec=shift @opt;
	my $optref=shift @opt;
	push @processed, $optspec => \&_collect;
    }
    return @processed;
}

sub passthrough2 {
    my ($exclude,@opt)=@_;
    @COLLECT=();
    %known_noarg_opts=();
    my @processed;
    while (@opt) {
	my $optspec=shift @opt;
	my $optref=shift @opt;
	next if $exclude->{$optspec};
	if ($optspec!~/=/) {
	    if ($optspec=~/^([-|\w\d_]+)(\!|$)/) {
		foreach my $subopt (split ('\|',$1)){
		    $known_noarg_opts{$subopt}=1 if not $2 or $2 eq '!';
		    $known_noarg_opts{'no-'.$subopt}=1 if $2 and $2 eq '!';
		    if ($verbose) {
			print STDERR "known_noarg_opts $subopt ($optspec)\n" if not $2 or $2 eq '!';
			print STDERR "known_noarg_opts no-$subopt ($optspec)\n" if $2 and $2 eq '!';
		    }
		}
	    }
	}
	push @processed, $optspec => \&_collect;
    }
    return @processed;
}

sub cat_options {
    my @out;
    for (my $i=0; $i<@COLLECT;$i++) {
	my $opt=$COLLECT[$i];
	if (defined $opt->[2]) {
	    push @out, '--'.$opt->[0],$opt->[1].'='.$opt->[2];
	} elsif (defined $opt->[1]) {
	    if ($opt->[1] ne '1') {
		push @out, '--'.$opt->[0],$opt->[1];
	    } elsif ($known_noarg_opts{$opt->[0]}) {
		push @out, '--'.$opt->[0];
	    } else {
		push @out, '--'.$opt->[0],$opt->[1];
	    }
	} else {
	    push @out, '--'.$opt->[0];
	}
    }
    return @out;
}

1;
