package Source::Repository::RPM;

use strict;
use warnings;
use Carp;
use RPM::Header;
use File::Find;

use Source::Repository;

our @ISA=qw/Source::Repository/;

#push @Source::Repository::Mass::ORIGIN_DEFAULT_OPTS,
#    -rpmfindsub => \&Source::Repository::RPM::find_highest_nested_rpm;
#push @Source::Repository::Mass::DEST_DEFAULT_OPTS,
#    -rpmfindsub => \&Source::Repository::RPM::find_highest_rpm;

sub new {
    my $self=shift;
    $self=$self->SUPER::new(@_);
    $self->{-rpmfindsub} ||= \&Source::Repository::RPM::find_highest_nested_rpm;
    return $self;
}

sub is_pkg {
   my ($self,$item)=@_;
   return if not (defined $item and -e $item and not -d $item);
   return $item=~/\.src\.rpm$/;
}

sub name2pkg {
    my ($self,$name)=@_;
    my $rh=&{$self->{-rpmfindsub}}($name,@{$self->{-path}});
    return unless $rh;
    return Source::Package->new(
	-name => $rh->{NAME},
	-version => $rh->{VERSION},
	-release => $rh->{RELEASE},
	-epoch => $rh->{EPOCH},
	-file => $rh->source_name,
	);
}

sub file2pkg {
    my ($self,$file)=@_;
    my $rh = new RPM::Header $file;
    die "Strange rpm file: $file" unless $rh;
    return Source::Package->new(
	-name => $rh->{NAME},
	-version => $rh->{VERSION},
	-release => $rh->{RELEASE},
	-epoch => $rh->{EPOCH},
	-file => $rh->source_name,
	);
}

### class method
sub pkg4rpmeditor {
    my ($class, $pkg)=@_;
    return [ SOURCERPM => $pkg->file];
}

#------------------------------------------
#    protected utilities
#------------------------------------------

sub find_highest_rpm {
    my $name=shift;
    my $cur_href;
    for my $path (@_) {
      PATH:
	for my $rpmfile (reverse(glob "$path/$name-*.src.rpm")) {
#	print STDERR "trying $rpmfile for $name\n";
	    my $href = new RPM::Header $rpmfile;
	    if ($name eq $href->{NAME}) {
		if (not $cur_href or $cur_href->cmpver($href)<0) {
		    $cur_href=$href;
		}
		# assume 1 rpm per name; false for jpp TODO:option!!!
		last PATH;
	    }
	}
    }
    return $cur_href;
}

sub find_highest_nested_rpm {
    my $name=shift;
    my $cur_href;
    for my $path (@_) {
      PATH:
	for my $rpmfile (&__prefind_src_rpms($name,$path)) {
#	print STDERR "trying $rpmfile for $name\n";
	    my $href = new RPM::Header $rpmfile;
	    if ($name eq $href->{NAME}) {
		if (not $cur_href or $cur_href->cmpver($href)<0) {
		    $cur_href=$href;
		}
	    }
	}
    }
    return $cur_href;
}

my @files;
sub __prefind_src_rpms {
    my ($name,@dirs)=@_;
    @files=();
    find (
	sub {
	    push @files, $File::Find::name if /^\Q$name\E-.*\.src\.rpm$/;
	}, @dirs);
    return @files;
}

sub find_first_rpm {
    my $name=shift;
    for my $path (@_) {
	for my $rpmfile (reverse(glob "$path/$name-*.src.rpm")) {
#	print STDERR "trying $rpm for $name\n";
	    my $href = new RPM::Header $rpmfile;
	    if ($name eq $href->{NAME}) {
		# assume 1 rpm per name; false for jpp TODO:option!!!
		return $href;
	    }
	}
    }
    return;
}


#------------------------------------------
#    private utilities
#------------------------------------------

1;
