package Source::Repository::RPM::ALTLinuxSrcList;

use strict;
use warnings;
use Carp;

use Source::Repository::RPM;

our @ISA=qw/Source::Repository::RPM/;

sub new {
    my $self=shift;
    $self=$self->SUPER::new(@_);
    my $path=$self->{-path}->[0];
    my $altsrclist=$path.'/../list/src.list';
    if (-e $altsrclist) {
	($self->{-names}, $self->{-name2pkg})=&__load_altsrclist($self,$altsrclist,$path);
    } else {
	die "Source::Repository::RPM::ALTLinuxSrcList: $altsrclist not found.";
    }
    return $self;
}

sub name2pkg {
    my ($self,$name)=@_;
    my $name2pkg=$self->{-name2pkg};
    return $name2pkg->{$name} if $name2pkg;
    return;
}


sub __load_altsrclist {
    my ($self,$list,$prefix)=@_;
    my @all_names;
    my %name2pkg;
    open (my $fn, '<', $list) or die "can't open file $list\n";
    while (my $line=<$fn>) {
	my @list = &Source::Repository::__line2array($line);
	next unless @list;
	my $name=$list[0];
	push @all_names, $name;
	$name2pkg{$name}=&altlinux_srclist_processor(\@list,$prefix);
    }
    close($fn);
    return \@all_names, \%name2pkg;
}


sub altlinux_srclist_processor {
    my ($ref,$prefix)=@_;
    return unless $ref;
    my ($epoch,$release);
    return unless @$ref;
    my ($name, $versionspec, $srpm)=@$ref;
    $epoch=$1 if $versionspec=~s/^(\d+)://;
    # warning: altlinux-specific, for src.list only
    $release=$1 if $versionspec=~s/-(alt.+)$//;
    # TODO: baseurl support
    return Source::Package->new(
	-name => $name,
	-epoch=> $epoch,
	-version => $versionspec,
	-release => $release,
	-file => $prefix.'/'.$srpm,
	);
}


1;
