package Source::Repository::RPM::ComponentContainer;

use strict;
use warnings;
use Carp;

use Source::Repository::RPM;
use Source::Repository::RPM::ALTLinuxSrcList;
our @ISA=qw/Source::Repository::RPM/;
our $verbose=1;

sub new {
    my $self=shift;
    $self=$self->SUPER::new(@_);
    confess "internal error: repository path not found" if not $self->{-path};
    my @components;
    foreach my $pathcomponent (@{$self->{-path}}) {
	next unless -d $pathcomponent;
	if (-e $pathcomponent.'/../list/src.list') {
	    print STDERR "RPM::ComponentContainer: selected ALTLinuxSrcList for $pathcomponent\n" if $verbose;
	    push @components, Source::Repository::RPM::ALTLinuxSrcList->new(%$self, -path => [$pathcomponent]);
	} elsif(substr($pathcomponent,-12) eq 'SRPMS.hasher') {
	    print STDERR "RPM::ComponentContainer: selected hasher for $pathcomponent\n" if $verbose;
	    push @components, Source::Repository::RPM->new(%$self, -path => [$pathcomponent], 
		   -rpmfindsub => \&Source::Repository::RPM::find_highest_rpm);
	} else {
	    print STDERR "RPM::ComponentContainer: selected  for $pathcomponent\n" if $verbose;
	    push @components, Source::Repository::RPM->new(%$self, -path => [$pathcomponent]);
	}
    }
    die "error: repository path $self->{-path} contains no valid components." unless @components;
    return $components[0] if $#components<1;
    $self->{-components}=\@components;
    return $self;
}

sub names {
    my ($self,$name)=@_;
    my @names;
    foreach my $component (@{$self->{-components}}) {
	push @names, $component->names();
    }
    return \@names;
}

sub name2pkg {
    my ($self,$name)=@_;
    # find first strategy; TODO: strategies (or subclasses?)
    foreach my $component (@{$self->{-components}}) {
	my $pkg=$component->name2pkg($name);
	return $pkg if $pkg;
    }
    return;
}

#------------------------------------------
#    private utilities
#------------------------------------------

1;
