package Source::Repository::Tarball;

use strict;
use warnings;

use File::Basename;
use Source::Repository;

our @ISA=qw/Source::Repository/;

sub is_pkg {
   my ($self,$item)=@_;
   return if not (defined $item and -e $item and not -d $item);
   my ($name)=$self->_get_name_version_format_from_filename($item);
   return defined $name;
}

sub file2pkg {
    my ($self,$file)=@_;
    return unless $file and -e $file;
    die "Oops: file2pkg: strange file $file" unless $self->is_pkg($file);
    my ($name,$version)=$self->_get_name_version_format_from_filename($file);
    return Source::Package->new(
	-name => $name,
	-version => $version,
	-file => $file,
	);
}

# protected, can be overriden in sublasses
sub _get_name_version_format_from_filename {
   my ($self,$item)=@_;
   return unless $item=~/^(.+)-([\d\.]+)\.(tar(?:\..+)?|tgz|tbz2?|txz|zip|7z|rar)$/i;
   return (basename($1),$2); # ,$3 - suffix; not used.
}

1;
